@@ -2,6 +2,7 @@ import multiprocessing
 import threading
 import argparse
 from FreeTAKServer.controllers.CreateStartupFilesController import CreateStartupFilesController
+CreateStartupFilesController()
 from FreeTAKServer.controllers.services.TCPDataPackageService import TCPDataPackageService as TCPFlaskFunctions
 from FreeTAKServer.controllers.services.SSLDataPackageService import SSLDataPackageService as SSLFlaskFunctions
 from FreeTAKServer.controllers.configuration.OrchestratorConstants import OrchestratorConstants
@@ -10,6 +11,7 @@ from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerControl
 from FreeTAKServer.controllers.services.RestAPI import RestAPI
 from FreeTAKServer.model.ServiceObjects.FTS import FTS as FTSObj
 from FreeTAKServer.model.SimpleClient import SimpleClient
+from FreeTAKServer.controllers.configuration_wizard import ask_user_for_config
 import time
 from FreeTAKServer.controllers.AddDataToCoTList import AddDataToCoTList
 from FreeTAKServer.model.FilterGroup import FilterGroup
@@ -186,8 +188,8 @@ class FTS:
             self.SSLClientDataPipe = Queue()
             SSLCoTServicePipeFTS = Queue()
             SSLCoTServicePipeController = Queue()
-            self.SSLCoTServicePipe = QueueManager(SSLCoTServicePipeController, SSLCoTServicePipeFTS)
-            SSLCoTServicePipe = QueueManager(SSLCoTServicePipeFTS, SSLCoTServicePipeController)
+            self.SSLCoTServicePipe = QueueManager(SSLCoTServicePipeFTS, SSLCoTServicePipeController)
+            SSLCoTServicePipe = QueueManager(SSLCoTServicePipeController, SSLCoTServicePipeFTS)
             self.SSLCoTPoisonPill = multiprocessing.Event()
             self.SSLCoTPoisonPill.set()
             self.ReceiveConnectionsReset = multiprocessing.Event()
@@ -599,7 +601,7 @@ class FTS:
                 self.start_all(StartupObject)
 
             while True:
-                #time.sleep(MainConfig.MainLoopDelay/1000)
+                time.sleep(MainConfig.MainLoopDelay/1000)
                 try:
                     self.checkPipes()
                 except Exception as e:
@@ -714,15 +716,21 @@ if __name__ == "__main__":
         parser.add_argument('-AutoStart', type=str, help='whether or not you want all services to start or only the root service and the RestAPI service', default='True')
         parser.add_argument('-UI', type=str, help="set to true if you would like to start UI on server startup")
         args = parser.parse_args()
-        AtakOfTheCerts().bake_startup()
+        if MainConfig.first_start:
+            ask_user_for_config()
+        else:
+            pass
+
+        with AtakOfTheCerts() as aotc:
+            aotc.generate_ca(expiry_time_secs=31536000)
+            aotc.bake(common_name="pubserver", cert="server", expiry_time_secs=31536000)
+            aotc.bake(common_name="user", cert="user", expiry_time_secs=31536000)
         import os
         if args.d:
             CreateStartupFilesController().create_daemon()
             os.system("systemd daemon-reload")
             os.system("systemctl start FreeTAKServer.service")
             exit(1)
-        else:
-            CreateStartupFilesController()
         FTS().startup(args.CoTPort, args.CoTIP, args.DataPackagePort, args.DataPackageIP, args.SSLDataPackagePort, args.SSLDataPackageIP, args.RestAPIPort, args.RestAPIIP, args.SSLCoTPort, args.SSLCoTIP, args.AutoStart, True, args.UI)
     except Exception as e:
         print(e)
