@@ -1,6 +1,6 @@
 class HashVariables:
     @classmethod
-    def CreateExCheckTemplate(cls):
+    def ExcheckUpdate(cls):
         cls.INTAG = None
         return cls
 
